Transifex FAQ — Transifex v0.9.0 documentation

# Transifex v0.9.0 documentation

# Transifex FAQ

- FAQ: General
  - Why does this project exist?
  - What does “Transifex” mean, and how do you pronounce it?
  - Who’s behind this?
  - Which sites use Django?
  - <L10n Platform X> does <feature Y> – why doesn’t Transifex?
  - Is Transifex a complete Localization platform?
  - How can I download the Transifex documentation to read it offline?
- FAQ: Using Transifex
  - Why do I get an error when ...
- FAQ: Contributing code
  - How can I get started contributing code to Transifex?
  - I submitted a bug fix several weeks ago. Why are you ignoring my patch?